@@ -1,10 +1,12 @@
 # this module will be loaded by ExtUtils/XSpp/Grammar.pm and needs to
 # define subroutines in the ExtUtils::XSpp::Grammar namespace
-package ExtUtils::XSpp::Grammar;
-
+package ExtUtils::XSpp::Lexer;
+# for the indexer and friends
 use strict;
 use warnings;
 
+package ExtUtils::XSpp::Grammar;
+
 use ExtUtils::XSpp::Node;
 use ExtUtils::XSpp::Node::Access;
 use ExtUtils::XSpp::Node::Argument;
@@ -196,7 +198,7 @@ sub yylex {
         return ( $tokens{$1}, $1 ) if exists $tokens{$1};
         return ( 'p_any', substr $1, 1 );
       } elsif( $$buf =~ s/^( \%}
-                      | \%{ | {\%
+                      | \%\{ | \{\%
                       | [{}();%~*&,=\/\.\-<>|]
                       | :: | :
                        )//x ) {
@@ -273,6 +275,7 @@ sub add_top_level_directive {
     ( $args{any},
       any_named_arguments      => $args{any_named_arguments},
       any_positional_arguments => $args{any_positional_arguments},
+      condition                => $parser->get_conditional,
       );
 }
 
